@@ -20,8 +20,7 @@ developed by KaisaGlobal quant team.
 import json, sys
 from os.path import dirname, abspath
 project_path = dirname(dirname(abspath(__file__)))
-SERVER = r'\common' if ('win' in sys.platform) else r'/common'
-projec_full_path = project_path + SERVER
+projec_full_path = project_path + r'\common'
 sys.path.append(projec_full_path)
 
 import requests
